<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>关于 </translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>联系</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>许可证： </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>屏幕截图和注释工具</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>捕获</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>包含光标</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>延迟</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>捕获模式</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>在图钉窗口中显示图像</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>图像复制到剪贴板</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>上传图像</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>打开图像父目录</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>保存图像</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>隐藏主窗口</translation>
    </message>
    <message>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>操作设置</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>操作</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>需要水印图像</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>请通过“选项”&gt;“设置”&gt;“注释器”&gt;“更新”添加水印图像</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>平滑绘制的路径</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>如启用，绘制完成后
消除笔和标记路径。</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>平滑因子</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>增加平滑因子将减少
笔和记号笔的精度，但会
使它们更平滑。</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>注释器设置</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>记住注释器选择并在启动时加载</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>绘制后切换到选择工具</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>数字工具种子更改将更新所有数字项目</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>禁用此选项将导致数字工具的更改
种子仅影响新项目，而不影响现有项目。
禁用此选项将允许重复的数字。</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>画布颜色</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>注释区域画布的默认背景颜色
改变颜色只会影响新的注释区域。</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>绘图后选择项目</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>启用此选项后，将在创建项目后对其进行选择，
从而可以更改设置。</translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>使用默认模式在启动时捕获屏幕截图</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>应用程序样式</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>设置定义GUI外观的应用程序样式。
更改要求ksnip重新启动才能生效。</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>应用程序设置</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>自动将新的捕获复制到剪贴板</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>使用标签</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>修改需要重启后生效。</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>以单实例模式运行 ksnip</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>当只有一个标签时隐藏标签栏。</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>启用这个选项将会只允许一个ksnip实例运行，
所有其它实例启动时会将参数传给第一个实例
然后退出。改变这个选项需要在关闭所有实例
后启动新的实例。</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>在移动时记住主窗口的位置并在启动时加载</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>自动隐藏标签</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>自动隐藏 Docks</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>在启动时隐藏工具栏和注释器，
可以按下 Tab 键显示 Dock。</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>自动调整内容大小</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>自动调整主窗口的大小以适合内容图像。</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>启用调试</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>启用写入控制台的调试输出。
更改需要 ksnip 重新启动才能生效。</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>根据内容大小是允许窗口管理器接收新内容的延迟。
如果未正确调整主窗口以适应新内容，
增加延迟可能会改善行为。</translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>贡献者：</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>西班牙语翻译</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>荷兰语翻译</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>俄语翻译</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>挪威语的翻译</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>法语翻译</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>波兰语翻译</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap 和 Flatpak 支持</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>作者：</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>警告 - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>捕获 %1%2%3 已经被修改。
是否需要保存？</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>用鼠标绘制一个矩形区域</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>捕获全屏，包括所有监视器</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>捕获鼠标所在的屏幕</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>捕获目前焦点所在的窗口</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>捕获当前在鼠标光标下的内容</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>捕获上一次选择的矩形区域的屏幕截图</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>使用 the screenshot Portal 截图</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>社区</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>错误报告</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>如果您有常规问题、想法或只想谈谈 ksnip，&lt;br/&gt;请加入我们的 %1 或我们的 %2 服务器。</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>请使用 %1 报告故障。</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>复制到剪切板失败</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>以 base64 图片编码形式复制到剪切板失败。</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>已复制到剪切板</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>已将图像的 base64 编码复制到剪切板。</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>删除图像</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>项目 &apos;%1&apos; 将被删除。
你想继续吗？</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>欢迎捐款</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip 是一个非盈利的 Copyleft 自由软件项目，并且&lt;br/&gt;仍有一些费用需要支付，&lt;br/&gt;如域名成本或跨平台支持的硬件成本。</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>&lt;br/&gt;如果你想通过请开发者喝啤酒或咖啡提供帮助或只是想赞赏所做的工作，欢迎看看%1这里%2。</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>成为 GitHub 赞助者？</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>也可以在 %1此处%2 捐款。</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>通过点击“添加”标签按钮来添加新的操作。</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>矩形区域</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>上一个矩形区域</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>全屏（所有监视器）</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>当前屏幕</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>活动的窗口</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>光标下的窗口</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>截图门户</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>强制匿名上传。</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP 上传器</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>上传成功</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>无法为上传保存临时图像。</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>无法启动进程，请检查路径和权限是否正确。</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>进程已崩溃</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>进程超时。</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>进程读错误。</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>进程写错误。</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>网络错误，请检查控制台输出。</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>上传失败</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>脚本在标准错误上有输出。</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP 上传成功完成。</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>未知错误。</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>连接错误。</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>权限错误。</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>脚本 %1 上传成功。</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>已上传至 %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>启用全局热键</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>捕获矩形区域</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>捕获全屏</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>捕获当前屏幕</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>捕捉活动的窗口</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>捕获光标下的窗口</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>全局热键</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>捕捉上一次的矩形区域</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>使用 Portal 捕获</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>当前仅 Windows 和 X11 支持热键。
禁用此选项也会使仅 ksnip 操作快捷方式。</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>截图时包含鼠标光标</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>屏幕截图时鼠标
光标是否可见。</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>图像采集器</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>使用 XDG-DESKTOP-PORTAL 的通用 Wayland 实现
以不同的方式处理屏幕缩放。
启用此选项将确定当前屏幕缩放
并将其
应用于 ksnip 中的屏幕截图 。</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME 和 KDE Plasma 支持各自的Wayland，
也有通用的 XDG-DESKTOP-PORTAL 屏幕截图。
启用该选项将强制 KDE Plasma 和 GNOME
使用 XDG-DESKTOP-PORTAL 截图方式。
改变这个选项需要重新启动 ksnip。</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>捕捉屏幕截图后显示主窗口</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>截图时隐藏主窗口</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>捕获一个新截图时隐藏主窗口。</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>隐藏或最小化主窗口时在捕获新的
屏幕快照后显示主窗口。</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>强制 Generic Wayland (xdg-desktop-portal) 截图</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>缩放 Generic Wayland (xdg-desktop-portal) 截图</translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur 历史记录</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>时间戳</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>链接</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>删除链接</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>上传到 imgur.com 完成！</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>收到新令牌，正在尝试再次上传…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur 令牌已过期，正在请求新令牌…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>强制匿名上传</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>总是将 Imgur 链接复制到剪贴板</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Client ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>客户端 Secret</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>输入Imgur Pin，它将会被替换为令牌。</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>获得 PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>获得令牌</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur 历史记录</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur上载程序</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>等待 imgur.com 的回应…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com 令牌已成功更新。</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com 令牌更新错误。</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>上传到Imgur后在默认浏览器中打开</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>直接链接到图片</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>基址 URL：</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>基地 URL 用来与 Imgur 通信。
更改需要重启应用。</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>清空 Token</translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>无法打开图片</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>无法从路径 %1 中打开图片</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>触发并捕获屏幕截图
的延迟秒数。</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>秒</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>将屏幕截图保存到文件</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>复制屏幕截图到剪贴板</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤消</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>剪裁</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>剪裁屏幕截图</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>未保存</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>上传</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>打开打印机设置对话框</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>打印预览</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>打开“打印预览”对话框，可以在其中更改图像方向</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>选项(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>添加水印</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>为捕获的图像添加水印。可以添加多个水印。</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>无法显示图像</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>另存为...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>嵌入粘贴</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>图钉</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>将截图固定在无边框的前台窗口上</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>需要提供一个图像。</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>打开目录</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>打开图像</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>显示 Docks</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>隐藏 Docks</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>复制为数据 URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>打开 &amp; 最近</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>修改画布</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>上传 triggerCapture 到外部源</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>复制 triggerCapture 到系统剪贴板</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>缩放图像</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>旋转</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>旋转图像</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>操作</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>图像文件</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>另存为</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>打开目录</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>捕获</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>关闭其它</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>关闭所有</translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>图像已重命名</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>图像重命名失败</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>重命名图像</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>新文件名：</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>成功将图片重命名为 %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>未能将图片重命名为 %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>另存为</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>图片已保存</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>保存图像失败</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>图像文件</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>已保存至 %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>未能将图片保存至 %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>自动将新的捕获保存到默认位置</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>在放弃未保存的更改之前提示保存</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>记住上次保存的目录</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>启用后每次保存都会将设置中的保存目录
覆盖为上次的保存目录。</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>捕获保存位置和文件名</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>支持 JPG、PNG 和 BMP 格式。如果没有提供格式，将使用PNG作为默认格式。
文件名可以包含以下通配符。
- $Y, $M, $D 代表日期，$h, $m, $s 代表时间，或 $T 代表 hhmmss 格式的时间。
- 多个连续的 # 代表计数器。若 #### 代表 0001，下一次捕获则会是0002。</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>保存设置</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>捕获保存位置</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>因子</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>保存质量</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>指定 0 可以获得小的压缩文件，100 会获得大的未压缩文件。
并非所有图像格式都像 JPEG 一样支持全部范围。</translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>将脚本输出复制到剪切板</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>脚本：</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>上传时调用的脚本的路径。在上传过程中，脚本将被以
临时 png 文件的路径作为单一参数调用。</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>上传脚本</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>选择上传脚本</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>在上传脚本输出至标准错误时停止</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>当脚本输出至标准错误时，将上传标记为失败。
没有此设置，脚本中的错误将不会被注意到。</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>过滤器：</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>正则表达式。仅在匹配上正则表达式时复制到剪贴板。
若省略此项，将复制所有内容。</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>图像采集器</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur 上传程序</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>注释器</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>上传程序</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>上传脚本</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>贴纸</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>截图区域</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>托盘图标</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>水印</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>操作</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP 上传器</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>使用控制柄调整所选矩形的大小，或通过拖动选区来移动它。</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>使用方向键移动选中区域。</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>按 CTRL 键的同时使用方向键移动左上角的控制柄。</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>按 ALT 键的同时使用方向键移动右下角的控制柄。</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>可以通过设置禁用此消息。</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>点击并拖动选择一个矩形区域或按 ESC 键退出。</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>选择后按住 CTRL 键调整选区大小。</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>选择后，按住 CTRL 键防止调整大小。</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>如果未进行选择，则60秒后将取消操作。</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>可以通过设置禁用此消息。</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>截图时冻结图像</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>启用后将在选择矩形区域时冻结背景。
它还会更改延迟屏幕截图的行为，
从而更改了延迟屏幕截图的行为，
启用此选项将延迟发生在显示剪裁区域之前，
而禁用此选项
将延迟发生在显示剪裁区域之后。
Wayland 始终禁用此功能，
MacOs 始终启用此功能。</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>在截屏区域显示放大镜</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>显示放大背景图的
放大镜。此设置仅在
启用了&apos;在截图时冻结图像&apos;时生效。</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>在截图区域显示标尺</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>在截屏区域，显示从屏幕边缘到鼠标
的水平线和垂直线。</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>显示截图区域的位置和尺寸信息</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>当未按下鼠标左键时，
显示位置，
当按下鼠标按钮时，
所选区域的大小显示在捕获区域的左上方。</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>默认情况下允许调整矩形区域的大小</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>启用后，
将在选择矩形区域后允许调整选择的大小。
完成调整大小后，
可以按回车键确认选择。</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>显示截图区域信息文本</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>截图区域的光标颜色</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>设置剪切区域光标的颜色。</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>截图区域的光标粗细</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>设置剪切区域光标的粗细。</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>截屏区域</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>截图区域装饰色</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>设置剪切区域上
所有装饰元素的颜色。</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>截图区域透明度</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>剪裁区域中未选择区域的 Alpha。
数字越小越透明。</translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>向下</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>使用默认贴纸</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>贴纸设置</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>矢量图像文件 (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>添加贴纸</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>显示编辑器</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>使用托盘图标</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>启用后，如系统窗口管理器支持，会向任务栏添加托盘图标。
更改需要重新启动才能生效。</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>最小化到托盘</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>启动时最小化到托盘</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>关闭到托盘</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>显示编辑器</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>捕获</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>默认托盘图标行为</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>左键单击托盘图标时的默认触发行为。</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>托盘图标设置</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>使用平台特定的通知服务</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>启用后将使用尝试使用特定于平台的通知存在时提供服务。
 更改需要重新启动才能生效。</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>显示托盘图标通知</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>选择图像</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>图片文件</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>需要上传脚本</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>请通过选项&gt;设置&gt;上传脚本添加一个上传脚本</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>捕获上传</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>您即将把图像上传至外部站点。您是否想要继续？</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>上传前请求确认</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>上传类型：</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>脚本</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>上传程序</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>构建版本</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>使用：</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>水印图像</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>旋转水印</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>启用后，将添加旋转 45° 的水印</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>水印设置</translation>
    </message>
</context>
</TS>
